# cpematcher

[![Build Status](https://travis-ci.com/alertot/cpematcher.svg?branch=master)](https://travis-ci.com/alertot/cpematcher)  [![PyPIersion](https://badge.fury.io/py/cpematcher.svg)](https://badge.fury.io/py/cpematcher)

## Overview

Match and compare CPEs.

## Installation / Usage

To install use pip:

    $ pip install cpematcher-ng



# Origin

The project was forked from [cpematcher](https://github.com/alertot/cpematcher). Kudos to the original author!
